@@ -17,6 +17,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 
+import os
 import sys
 
 from PyQt5.QtGui import QFontDatabase
@@ -37,6 +38,7 @@ def populate_font_database():
 
 
 def main():
+    os.environ["QT_AUTO_SCREEN_SCALE_FACTOR"] = "1"
     app = QApplication(sys.argv)
     populate_font_database()
     window = MainWind()
